@@ -1,5 +1,6 @@
+import urllib.parse
+
 from .common import InfoExtractor
-from ..compat import compat_parse_qs
 from ..utils import ExtractorError
 
 
@@ -9,22 +10,18 @@ class BokeCCBaseIE(InfoExtractor):
             r'<(?:script|embed)[^>]+src=(?P<q>["\'])(?:https?:)?//p\.bokecc\.com/(?:player|flash/player\.swf)\?(?P<query>.+?)(?P=q)',
             webpage, 'player params', group='query')
 
-        player_params = compat_parse_qs(player_params_str)
+        player_params = urllib.parse.parse_qs(player_params_str)
 
         info_xml = self._download_xml(
-            'http://p.bokecc.com/servlet/playinfo?uid=%s&vid=%s&m=1' % (
+            'http://p.bokecc.com/servlet/playinfo?uid={}&vid={}&m=1'.format(
                 player_params['siteid'][0], player_params['vid'][0]), video_id)
 
-        formats = [{
+        return [{
             'format_id': format_id,
             'url': quality.find('./copy').attrib['playurl'],
             'quality': int(quality.attrib['value']),
         } for quality in info_xml.findall('./video/quality')]
 
-        self._sort_formats(formats)
-
-        return formats
-
 
 class BokeCCIE(BokeCCBaseIE):
     _IE_DESC = 'CC视频'
@@ -40,11 +37,11 @@ class BokeCCIE(BokeCCBaseIE):
     }]
 
     def _real_extract(self, url):
-        qs = compat_parse_qs(self._match_valid_url(url).group('query'))
+        qs = urllib.parse.parse_qs(self._match_valid_url(url).group('query'))
         if not qs.get('vid') or not qs.get('uid'):
             raise ExtractorError('Invalid URL', expected=True)
 
-        video_id = '%s_%s' % (qs['uid'][0], qs['vid'][0])
+        video_id = '{}_{}'.format(qs['uid'][0], qs['vid'][0])
 
         webpage = self._download_webpage(url, video_id)
 
